@@ -1,7 +1,7 @@
 library(teachingApps)
 <<<<<<< HEAD
-needs::needs(shiny, plotly)
+pacman::p_load(shiny, plotly)
 =======
-needs::needs(shiny, plotly)
+pacman::p_load(shiny, plotly)
 dirs <- list.dirs(system.file('examples',package = 'shiny'), recursive = F)
 >>>>>>> 725cde6e3cf3d4f401624356a8d30a138358fcc1
